@@ -1,18 +1,18 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2012 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2015 -- leonerd@leonerd.org.uk
 
 package Parser::MGC;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Carp;
 
-use File::Slurp qw( slurp );
+use File::Slurp::Tiny qw( read_file );
 
 =head1 NAME
 
@@ -225,11 +225,13 @@ this can be used to set the encoding of the file.
 sub from_file
 {
    my $self = shift;
-   my ( $filename, %opts ) = @_;
+   my ( $file, %opts ) = @_;
 
-   $self->{filename} = $filename;
+   $self->{filename} = $file;
 
-   $self->from_string( scalar( slurp $filename, binmode => $opts{binmode} ) );
+   $self->from_string( ref $file ?
+      do { local $/; binmode $file, $opts{binmode} if $opts{binmode}; <$file> } :
+      ( read_file $file, binmode => $opts{binmode} ) );
 }
 
 =head2 $result = $parser->from_reader( \&reader )
